@@ -33,7 +33,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: config.h,v 1.28 2008-11-13 18:23:41 f Exp $
+ * $Id: config.h,v 1.29 2009-07-28 16:42:18 f Exp $
  */
 
 #ifndef __config_h_
@@ -351,9 +351,9 @@
 #define DEFAULT_STATUS_CLOCK "[time %y7%T%y6]"
 
 #if defined(OPERVISION)
-#define DEFAULT_STATUS_FORMAT "%y1[%y2%R%y6] %* %B%H%A%S %W %F %> [%y2%!S%y6]"
+#define DEFAULT_STATUS_FORMAT "%y1[%y2%R%y6] %* %B%H%A%S %W %F %> [%y2%!S%y6]%y0"
 #else  /* OPERVISION */
-#define DEFAULT_STATUS_FORMAT "%y1[%y2%R%y6] %* %B%H%A%S %W %F %>"
+#define DEFAULT_STATUS_FORMAT "%y1[%y2%R%y6] %* %B%H%A%S %W %F %>%y0"
 #endif /* OPERVISION */
 
 #define DEFAULT_STATUS_FORMAT1 "%y1[%y2%R%y6] %y2%*%y6%y3%@%y6%y7%N%y6%#%C%+%A%Q%S%I%O %y3%W%y6 %F%y9%H%y6 %> [lj %y5%3%y6]%y0"
