@@ -29,7 +29,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: vars.h,v 1.9 2008-12-01 15:41:36 f Exp $
+ * $Id: vars.h,v 1.11 2009-12-21 14:14:17 f Exp $
  */
 
 #ifndef __vars_h_
@@ -110,6 +110,7 @@ enum {
 	CTCP_REPLY_IGNORE_SECONDS_VAR,
 	DCC_BLOCK_SIZE_VAR,
 /**************************** PATCHED by Flier ******************************/
+	DCC_HOST_VAR,
 	DCC_PORTS_VAR,
 /****************************************************************************/
 	DEBUG_VAR,
@@ -120,6 +121,10 @@ enum {
 /****************************************************************************/
 	DISPLAY_ENCODING_VAR,
 	EIGHT_BIT_CHARACTERS_VAR,
+/**************************** PATCHED by Flier ******************************/
+	ENCRYPT_PAD_MSGS_VAR,
+	ENCRYPT_PAD_PUBLIC_VAR,
+/****************************************************************************/
 	ENCRYPT_PROGRAM_VAR,
 	EXEC_PROTECTION_VAR,
 	FLOOD_AFTER_VAR,
@@ -191,6 +196,9 @@ enum {
 	OLD_ENCRYPT_PROGRAM_VAR,
 	REALNAME_VAR,
 	SAME_WINDOW_ONLY_VAR,
+/**************************** PATCHED by Flier ******************************/
+	SAVE_ENCRYPTION_KEYS_VAR,
+/****************************************************************************/
 	SCREEN_OPTIONS_VAR,
 	SCROLL_VAR,
 /**************************** PATCHED by Flier ******************************/
