@@ -31,12 +31,12 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: irc.c,v 1.136 2008-12-29 08:59:13 f Exp $
+ * $Id: irc.c,v 1.138 2009-12-21 15:08:26 f Exp $
  */
 
-#define IRCII_VERSION	"20081231"	/* YYYYMMDD */
+#define IRCII_VERSION	"20091223"	/* YYYYMMDD */
 /**************************** PATCHED by Flier ******************************/
-#define SCROLLZ_VERSION "2.0"
+#define SCROLLZ_VERSION "2.1"
 /****************************************************************************/
 
 #include "irc.h"
@@ -265,7 +265,7 @@ char  defban;
 char  bold=2;
 char  *DefaultServer=(char *) 0;
 char  *ScrollZstr=(char *) 0;
-char  *ScrollZver="ircII " IRCII_VERSION "+ScrollZ " SCROLLZ_VERSION " (30.12.2008)+Cdcc v" CDCC_VERSION;
+char  *ScrollZver="ircII " IRCII_VERSION "+ScrollZ " SCROLLZ_VERSION " (23.12.2009)+Cdcc v" CDCC_VERSION;
 char  *ScrollZver1=(char *) 0;
 #ifdef EXTRA_STUFF
 char  *EString=(char *) 0;
@@ -360,7 +360,7 @@ char  *ShowChanChannels=(char *) 0;
 char  *OperNick=(char *) 0;
 char  *OperPassword=(char *) 0;
 #endif
-#ifdef HAVE_MIRACL
+#ifdef HAVE_GMP
 char  MyPrivKey[mybufsize / 2];
 char  MyPubKey[mybufsize / 2];
 #endif
@@ -606,7 +606,7 @@ char VersionInfo[] = {
     '-',
     '8',
 #endif
-#ifdef HAVE_MIRACL
+#ifdef HAVE_GMP
     ' ',
     'F',
     'i',
