@@ -32,7 +32,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: names.c,v 1.59 2006/04/30 14:15:43 f Exp $
+ * $Id: names.c,v 1.62 2008-11-10 15:28:48 f Exp $
  */
 
 #include "irc.h"
@@ -493,9 +493,10 @@ ChannelList *add_to_channel(channel, nick, server, oper, halfop, voice, userhost
                         ischop = 1;
                         nick++;
                     }
-                    else if (*tmpnick == '&' || *tmpnick == '~') {
+                    else if (*tmpnick == '&' || *tmpnick == '~' || *tmpnick == '!') {
                         nick++;
                     }
+                    else break;
                     tmpnick++;
                 }
                 if (ishalfop && !my_stricmp(nick, get_server_nickname(server)))
@@ -765,6 +766,7 @@ char    *servmodes;
             if (isserver) userhost = NULL;
             *servmodeadd = '\0';
             *tmpbufmode = '\0';
+            *modebuf = '\0';
             *servline = '\0';
             *lastdeop = '\0';
             *lastvoice = '\0';
