@@ -31,7 +31,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: notice.c,v 1.35 2006/03/22 17:16:49 f Exp $
+ * $Id: notice.c,v 1.37 2008-03-14 16:13:22 f Exp $
  */
 
 #include "irc.h"
@@ -349,9 +349,14 @@ parse_notice(from, Args)
 							    do_hook(type, "%s %s %s", from, to, line))
 /**************************** Patched by Flier ******************************/
 								/*put_it("%s-%s:%s-%s %s", high, from, to, high, line);*/
+                                                        {
+                                                            char *cstr = empty_string;
+                                                            
+                                                            if (iscrypted == 2) cstr = "[*]";
+                                                            else if (iscrypted) cstr = "[!]";
                                                             put_it("%s%s%s-%s:%s-%s %s",
-                                                                   iscrypted ? "[!]" : "",
-                                                                   stampbuf, high, from, to, high, line);
+                                                                   cstr, stampbuf, high, from, to, high, line);
+                                                        }
                                                         if (ChanLog) {
                                                             ChannelList *chan;
 
@@ -540,7 +545,8 @@ got_initial_version(line)
             return;
         }
 /****************************************************************************/
-	reconnect_all_channels(parsing_server_index);
+	if (get_int_var(AUTO_RECONNECT_CHANNELS_VAR))
+		reconnect_all_channels(parsing_server_index);
 	reinstate_user_modes(/* parsing_server_index */); /* XXX */
 	maybe_load_ircrc();
 	if (server_list[parsing_server_index].away)
