@@ -32,7 +32,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: numbers.c,v 1.82 2006/04/30 14:15:43 f Exp $
+ * $Id: numbers.c,v 1.90 2008-09-15 16:49:28 f Exp $
  */
 
 #include "irc.h"
@@ -635,6 +635,9 @@ channel_topic(from, ArgList)
 {
 	char	*topic, *channel;
 /**************************** Patched by Flier ******************************/
+        int iscrypted;
+        char *cstr = "";
+        char tmpbuf[BIG_BUFFER_SIZE + 1];
         ChannelList *chan;
 
         topic = channel = NULL;
@@ -647,7 +650,12 @@ channel_topic(from, ArgList)
 		message_from(channel, LOG_CRAP);
 /**************************** Patched by Flier ******************************/
 		/*put_it("%s Topic for %s: %s", numeric_banner(), channel,*/
-		put_it("%sTopic for %s: %s", numeric_banner(), channel,
+		strmcpy(tmpbuf, topic, sizeof(tmpbuf));
+                iscrypted = DecryptMessage(tmpbuf, channel);
+                if (iscrypted == 2) cstr = "[*]";
+                else if (iscrypted) cstr = "[!]";
+                if (iscrypted) topic = tmpbuf;
+                put_it("%sTopic for %s%s: %s", numeric_banner(), cstr, channel,
 /****************************************************************************/
 			topic);
 	}
@@ -790,10 +798,10 @@ cannot_join_channel(from, ArgList)
 /**************************** PATCHED by Flier ******************************/
         /*PasteArgs(ArgList, 0);
 	strcpy(buffer, ArgList[0]);*/
-        if (-current_numeric == 437) {
+        if (-current_numeric == 437 || -current_numeric == 479) {
             /* special case for ircd 2.9 */
             strmcpy(buffer, ArgList[0], sizeof(buffer));
-            strmcat(buffer, " Cannot join channel ", sizeof(buffer));
+            strmcat(buffer, " Cannot join channel", sizeof(buffer));
         }
         else if (-current_numeric == 515) {
             PasteArgs(ArgList, 1);
@@ -856,6 +864,9 @@ cannot_join_channel(from, ArgList)
 		case 477:
 			strmcat(buffer, " (You must first identify yourself with NickServ to join that channel)", sizeof(buffer));
                         break;
+		case 479:
+			strmcat(buffer, " (Illegal channel name)", sizeof(buffer));
+			break;
 		case 515:
 			strmcat(buffer, " (You need to be identified to join that channel)", sizeof(buffer));
                         break;
@@ -1326,7 +1337,7 @@ numbered_command(from, comm, ArgList)
 /**************************** Patched by Flier ******************************/
                 if (server_list[parsing_server_index].connected) {
                     tmpnick=tmpbuf;
-                    if (DisplayNickInfo())
+                    if (DisplayNickInfo() && get_int_var(SEND_USERHOST_ON_NICK_IN_USE_VAR))
                         userhost(NULL,next_arg(tmpnick,&tmpnick),NULL); /* uhost - Zakath */
                 }
                 else {
@@ -1401,6 +1412,7 @@ numbered_command(from, comm, ArgList)
  	case 476:		/* #define ERR_BADCHANMASK      476 */
 /**************************** PATCHED by Flier ******************************/
  	case 477:               /* restricted to identified users */
+	case 479:		/* illegal channel name */
  	case 276:               /* hybrid7 - virtual channels       */
  	case 515:               /* freenode - restricted to identified users */
 /****************************************************************************/
@@ -1418,7 +1430,12 @@ numbered_command(from, comm, ArgList)
                  */
                 for (chan = server_list[from_server].chan_list; chan; chan = chan->next) {
                     if (!(chan->gotbans) || !(chan->gotwho)) {
-                        chan->repeatexceptions = 1;
+                        if (server_list[from_server].SZUnban > 2)
+                            server_list[from_server].SZUnban--;
+                        else server_list[from_server].SZUnban = 0;
+                        /* But only if we don't have operator status */
+                        if (!HAS_OPS(chan->status))
+                            chan->repeatexceptions = 1;
                         break;
                     }
                 }
@@ -1434,7 +1451,80 @@ numbered_command(from, comm, ArgList)
                 set_server_umode_flag(parsing_server_index,'r',1);
 /****************************************************************************/
 		break;
+/**************************** PATCHED by Flier ******************************/
+        case 671:		/* #define RPL_WHOISSECURE	671 */
+                whois_secure(from, ArgList);
+                break;
+/****************************************************************************/
 
+	case 730:	/* RPL_MONONLINE :serv 730 nick :n!u@h[,n!u@h,...] */
+	{
+		char buf[512];
+		char *p;
+
+		if (do_hook(current_numeric, "%s %s", from, ArgList[0])) {
+			if (strchr(ArgList[0], ','))
+			{
+				strmcpy(buf, ArgList[0], sizeof(buf));
+				for (p = strtok(buf, ","); p; p = strtok(NULL, ","))
+					say("Now online: %s", p);
+			}
+			else
+				say("Now online: %s", ArgList[0]);
+		}
+		break;
+	}
+	case 731:	/* RPL_MONOFFLINE :serv 731 nick :nick[,nick2,...] */
+	{
+		char buf[512];
+		char *p;
+
+		if (do_hook(current_numeric, "%s %s", from, ArgList[0])) {
+			if (strchr(ArgList[0], ',')) {
+				strmcpy(buf, ArgList[0], sizeof(buf));
+				for (p = strtok(buf, ","); p; p = strtok(NULL, ","))
+					say("Now offline: %s", p);
+			}
+			else
+				say("Now offline: %s", ArgList[0]);
+		}
+		break;
+	}
+	case 732:	/* RPL_MONLIST :serv 732 nick :nick[,nick2,...] */
+	{
+		char buf[512];
+		char *p;
+
+		if (do_hook(current_numeric, "%s %s", from, ArgList[0])) {
+			if (strchr(ArgList[0], ',')) {
+				strmcpy(buf, ArgList[0], sizeof(buf));
+				for (p = strtok(buf, ","); p; p = strtok(NULL, ","))
+					say("Monitoring: %s", p);
+			}
+			else
+				say("Monitoring: %s", ArgList[0]);
+		}
+		break;
+	}
+	/* RPL_MONLISTFULL :serv 734 nick limit nick[,nick2,...] :Monit... */
+	case 734:
+	{
+		char buf[512];
+		char *p;
+
+		if (do_hook(current_numeric, "%s %s", from, ArgList[0])) {
+			say("Monitor list full (limit %s)", ArgList[0]);
+			if (strchr(ArgList[1], ',')) {
+				strmcpy(buf, ArgList[1], sizeof(buf));
+				for (p = strtok(buf, ","); p; p = strtok(NULL, ","))
+					say("Could not add %s to monitor list", p);
+			}
+			else
+				say("Could not add %s to monitor list", ArgList[1]);
+		}
+		break;
+	}
+	
 		/*
 		 * The following accumulates the remaining arguments
 		 * in ArgSpace for hook detection.  We can't use
@@ -1496,6 +1586,12 @@ numbered_command(from, comm, ArgList)
                             OnBans(ArgList,comm == 348 ? 1 : 0);
                             skipit = 1;
                         }
+                        else if (comm == 349 && server_list[from_server].SZUnban) {
+                            if (server_list[from_server].SZUnban > 2)
+                                server_list[from_server].SZUnban--;
+                            else server_list[from_server].SZUnban = 0;
+                            skipit = 1;
+                        }
                         else
 /****************************************************************************/
  			i = do_hook(current_numeric, "%s %s", from, ArgSpace);
@@ -1761,8 +1857,13 @@ numbered_command(from, comm, ArgList)
 #define RPL_CLOSEEND         363
 #define RPL_SERVLISTEND      235
 		case 315:		/* #define RPL_ENDOFWHO         315 */
-			if (cannot_open != (char *) 0)
-				yell("Cannot open: %s", cannot_open);
+			if (who_mask & WHO_FILE) {
+				if (cannot_open != (char *) 0) {
+					yell("Cannot open: %s", cannot_open);
+					cannot_open = (char *) 0;
+				}
+				who_mask &= ~WHO_FILE;
+			}
 
 		case 323:               /* #define RPL_LISTEND          323 */
 			funny_print_widelist();
@@ -1821,6 +1922,7 @@ numbered_command(from, comm, ArgList)
 		case 394:		/* #define RPL_ENDOFUSERS       394 */
 /**************************** PATCHED by Flier ******************************/
 		case 349:               /* end of exception list */
+		case 733:		/* RPL_ENDOFMONLIST */
 /****************************************************************************/
 			if (!get_int_var(SHOW_END_OF_MSGS_VAR))
 				break;
