@@ -31,7 +31,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: vars.c,v 1.37 2008-12-01 15:41:36 f Exp $
+ * $Id: vars.c,v 1.39 2009-12-21 14:14:17 f Exp $
  */
 
 #include "irc.h"
@@ -59,6 +59,7 @@
 extern char *HelpPathVar;
 extern char *TimeStampString;
 extern time_t LastTS;
+extern struct in_addr forced_ip_addr;
 /****************************************************************************/
 
 #define	VF_NODAEMON	0x0001
@@ -97,6 +98,7 @@ static  void    SetScrollZstr _((char *));
 static  void    SetMaxModes _((int));
 static  void    SetMaxWallopNicks _((int));
 static  void    SetDCCBlockSize _((int));
+static  void    SetDCCHost _((char *));
 static  void    SetDCCPorts _((char *));
 static	void	Cnotifystring _((char *));
 static  void    SetAwayFile _((char *));
@@ -157,6 +159,7 @@ IrcVariable irc_variable[] =
 /**************************** PATCHED by Flier ******************************/
 /*        { "DCC_BLOCK_SIZE",		INT_TYPE_VAR,	DEFAULT_DCC_BLOCK_SIZE, NULL, NULL, 0, 0 },*/
 	{ "DCC_BLOCK_SIZE",		INT_TYPE_VAR,	DEFAULT_DCC_BLOCK_SIZE, NULL, SetDCCBlockSize, 0, 0 },
+	{ "DCC_HOST",		        STR_TYPE_VAR,	0, NULL, SetDCCHost, 0, 0 },
 	{ "DCC_PORTS",		        STR_TYPE_VAR,	0, NULL, SetDCCPorts, 0, 0 },
 /****************************************************************************/
 	{ "DEBUG",			INT_TYPE_VAR,	0, NULL, NULL, 0, 0 },
@@ -167,6 +170,10 @@ IrcVariable irc_variable[] =
 /****************************************************************************/
 	{ "DISPLAY_ENCODING",		STR_TYPE_VAR,	0, NULL, set_display_encoding, 0, 0 },
 	{ "EIGHT_BIT_CHARACTERS",	BOOL_TYPE_VAR,	DEFAULT_EIGHT_BIT_CHARACTERS, NULL, eight_bit_characters, 0, 0 },
+/**************************** PATCHED by Flier ******************************/
+	{ "ENCRYPT_PAD_MSGS",		BOOL_TYPE_VAR,	DEFAULT_DISPLAY_ANSI, NULL, 0, 0, 0 },
+	{ "ENCRYPT_PAD_PUBLIC",		BOOL_TYPE_VAR,	DEFAULT_DISPLAY_ANSI, NULL, 0, 0, 0 },
+/****************************************************************************/
 	{ "ENCRYPT_PROGRAM",		STR_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
 	{ "EXEC_PROTECTION",		BOOL_TYPE_VAR,	DEFAULT_EXEC_PROTECTION, NULL, exec_warning, 0, VF_NODAEMON },
 	{ "FLOOD_AFTER",		INT_TYPE_VAR,	DEFAULT_FLOOD_AFTER, NULL, NULL, 0, 0 },
@@ -248,6 +255,9 @@ IrcVariable irc_variable[] =
 	{ "OLD_ENCRYPT_PROGRAM",	BOOL_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
 	{ "REALNAME",			STR_TYPE_VAR,	0, 0, set_realname, 0, VF_NODAEMON },
 	{ "SAME_WINDOW_ONLY",		BOOL_TYPE_VAR,	DEFAULT_SAME_WINDOW_ONLY, NULL, NULL, 0, 0 },
+/**************************** PATCHED by Flier ******************************/
+        { "SAVE_ENCRYPTION_KEYS",		BOOL_TYPE_VAR,	0, NULL, NULL, 0, 0 },
+/****************************************************************************/
 	{ "SCREEN_OPTIONS", 		STR_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
 	{ "SCROLL",			BOOL_TYPE_VAR,	DEFAULT_SCROLL, NULL, set_scroll, 0, 0 },
 /**************************** PATCHED by Flier ******************************/
@@ -990,6 +1000,22 @@ int value;
     set_int_var(DCC_BLOCK_SIZE_VAR,value);
 }
 
+static void SetDCCHost(value)
+char *value;
+{
+    if (value && *value) {
+        struct in_addr inp;
+        struct hostent *hp;
+
+        if (inet_aton(value, &inp) == 0) {
+            if ((hp = gethostbyname(value)) != NULL)
+                bcopy(hp->h_addr, (char *) &forced_ip_addr, sizeof(forced_ip_addr));
+            else say("DNS lookup for %s failed", value);
+        }
+        else bcopy(&inp, (char *) &forced_ip_addr, sizeof(forced_ip_addr));
+    }
+}
+
 static void SetDCCPorts(value)
 char *value;
 {
